package zero1hd.rhythmbullet.graphics.ui.components;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.CheckBox;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;
import com.badlogic.gdx.utils.Align;

import zero1hd.rhythmbullet.screens.MainMenu;

public class GraphicsOptions extends Table {
	private Label resolutions, shaders;
	private Preferences prefs;
	private CheckBox glowShader, enhancedGlow;
	
	private ResolutionButton 
	_3840x2160,
	_2560x1440,
	_1920x1200,
	_1920x1080,
	_1280x800,
	_1280x720,
	_1366x768,
	_800x480;
	
	
	public GraphicsOptions(MainMenu mainMenu, Skin skin, Preferences prefs) {
		align(Align.center);
		defaults().space(10f);
		this.prefs = prefs;
		shaders = new Label("OpenGL Shaders", skin);
		add(shaders).fillX();
		row();
		
		glowShader = new CheckBox(" Glow Shader", skin);
		glowShader.setChecked(prefs.getBoolean("glow shader", true));
		glowShader.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				save();
				if (glowShader.isChecked()) {
					mainMenu.loadShaders();
					enhancedGlow.setDisabled(false);
				} else {
					enhancedGlow.setChecked(false);
					enhancedGlow.setDisabled(true);
					mainMenu.unloadShaders();
				}
			}
		});
		add(glowShader);
		row();
		
		enhancedGlow = new CheckBox(" Enhanced Glow", skin);
		enhancedGlow.setChecked(prefs.getBoolean("enhanced glow", false));
		enhancedGlow.setDisabled(!prefs.getBoolean("glow shader", false));
		enhancedGlow.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				save();
				if (enhancedGlow.isChecked()) {
					mainMenu.setBlurlvl(5);
				} else {
					mainMenu.setBlurlvl(1);
				}
			}
		});
		add(enhancedGlow);
		row();
		
		resolutions = new Label("Resolutions: ", skin);
		add(resolutions).left();
		row();
		
		
		TextButton fullscreen = new TextButton("Fullscreen", skin);
		fullscreen.addListener(new ChangeListener() {
			
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				if (!Gdx.graphics.isFullscreen()) {
					Gdx.graphics.setFullscreenMode(Gdx.graphics.getDisplayMode());
					prefs.putBoolean("fullscreen", true);
					prefs.flush();
				}
			}
		});
		add(fullscreen).fillX();
		row();
		
		_3840x2160 = new ResolutionButton(3840, 2160, skin, prefs);
		add(_3840x2160).fillX();
		row();
		
		_2560x1440 = new ResolutionButton(2560, 1440, skin, prefs);
		add(_2560x1440).fillX();
		row();
		
		_1920x1200 = new ResolutionButton(1920, 1200, skin, prefs);
		add(_1920x1200).fillX();
		row();
		
		_1920x1080 = new ResolutionButton(1920, 1080, skin, prefs);
		add(_1920x1080).fillX();
		row();
		
		_1280x800 = new ResolutionButton(1280, 800, skin, prefs);
		add(_1280x800).fillX();
		row();
		
		_1280x720 = new ResolutionButton(1280, 720, skin, prefs);
		add(_1280x720).fillX();
		row();
		
		_1366x768 = new ResolutionButton(1366, 768, skin, prefs);
		add(_1366x768).fillX();
		row();
		
		_800x480 = new ResolutionButton(800, 480, skin, prefs);
		add(_800x480).fillX();
		row();
		pack();
	}
	
	public void save() {
		Gdx.app.debug("Preferences", "Saved shading values values.");
		prefs.putBoolean("glow shader", glowShader.isChecked());
		prefs.putBoolean("enhanced glow", enhancedGlow.isChecked());
	}
}
