package zero1hd.rhythmbullet.graphics.ui.pages;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Vector3;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.ProgressBar;
import com.badlogic.gdx.scenes.scene2d.ui.Slider;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.ui.TextField;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;
import com.badlogic.gdx.utils.Align;

import zero1hd.rhythmbullet.RhythmBullet;
import zero1hd.rhythmbullet.audio.SongListController;
import zero1hd.rhythmbullet.screens.CreativeScreen;
import zero1hd.rhythmbullet.screens.MainMenu;

public class OptionsPage extends Page {
	Table optionsTable = new Table();
	private ProgressBar musicVolSlider;
	private ProgressBar fxVolSlider;
	private TextField directoryField;
	
	private float musicSearchTimer;
	public OptionsPage(RhythmBullet core, Vector3 targetPosition, KeybindOptionsPage moreOptionsPage, SongListController sc) {
		super("General", core.getDefaultSkin());
		setTextureBackground(core.getAssetManager().get("gradients.atlas", TextureAtlas.class).findRegion("red-round"));
		//Back button
		TextButton backButton = new TextButton("Back", core.getDefaultSkin());
		backButton.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				targetPosition.x = 0.5f*Gdx.graphics.getWidth();
			}
		});
		backButton.setPosition(10, getHeightBelowTitle() + 5);
		addActor(backButton);
		backButton.setWidth(backButton.getWidth() + 20);
		addSpaceToTitle(backButton.getWidth() + backButton.getX() + 20);
		
		optionsTable.align(Align.center);
		optionsTable.defaults().space(10f).padBottom(25f).expandY();
		optionsTable.setPosition(0, 0);
		optionsTable.setSize(getWidth(), getHeightBelowTitle() - 5);
		addActor(optionsTable);
		
		Label musicVolSliderLabel = new Label("Music Volume: ", core.getDefaultSkin());
		optionsTable.add(musicVolSliderLabel).left();
		musicVolSlider = new Slider(0, 100, 0.1f, false, core.getDefaultSkin());
		musicVolSlider.setValue(core.getPrefs().getFloat("music vol", 100f)*100f);
		optionsTable.add(musicVolSlider).spaceRight(15f).prefWidth(0.5f*getWidth()).fillX();
		final Label musicVolPercentage = new Label(MathUtils.round(musicVolSlider.getValue()) + "%", core.getDefaultSkin());
		musicVolSlider.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				musicVolPercentage.setText(MathUtils.round(musicVolSlider.getValue()) + "%");
				sc.getCurrentSong().setVolume(musicVolSlider.getPercent());
				
				core.getPrefs().putFloat("music vol", musicVolSlider.getPercent());
			}
		});
		optionsTable.add(musicVolPercentage).left();
		
		optionsTable.row();
		
		Label fxVolSliderLabel = new Label("FX Volume: ", core.getDefaultSkin());
		optionsTable.add(fxVolSliderLabel).left();
		fxVolSlider = new Slider(0, 100, 0.1f, false, core.getDefaultSkin());
		fxVolSlider.setValue(core.getPrefs().getFloat("fx vol", 100f)*100f);
		optionsTable.add(fxVolSlider).spaceRight(15f).prefWidth(0.5f*getWidth()).fillX();
		final Label fxVolPercentage = new Label(MathUtils.round(fxVolSlider.getValue()) + "%", core.getDefaultSkin());
		fxVolSlider.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				fxVolPercentage.setText(MathUtils.round(fxVolSlider.getValue()) + "%");
				core.getPrefs().putFloat("fx vol", fxVolSlider.getPercent());
			}
		});
		
		optionsTable.add(fxVolPercentage).left();
		
		optionsTable.row();
		
		Label musicDirectoryLabel = new Label("Music Directory: ", core.getDefaultSkin());
		optionsTable.add(musicDirectoryLabel).left();
		Label songCount = new Label("Songs: " + sc.getSongList().getAmountOfSongs(), core.getDefaultSkin(), "sub-font", core.getDefaultSkin().getColor("default"));
		directoryField = new TextField(null, core.getDefaultSkin() ) {
			@Override
			public void act(float delta) {
				if (musicSearchTimer > 0) {
					musicSearchTimer -= delta;
					if (musicSearchTimer <= 0) {
						sc.getSongList().setSearchPath(directoryField.getText());
						sc.getSongList().refresh();
						songCount.setText("Songs: " + sc.getSongList().getAmountOfSongs());
					}
				}
				super.act(delta);
			}
		};
		directoryField.setText(core.getPrefs().getString("music dir", System.getProperty("user.home")+System.getProperty("file.separator")+"Music"));
		directoryField.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				musicSearchTimer = 2;
				songCount.setText("...");
			}
		});
		optionsTable.add(directoryField).fillX();
		optionsTable.add(songCount).left();
		
		optionsTable.row();
		
		Label debugCodeLabel = new Label("Debug Code: ", core.getDefaultSkin());
		optionsTable.add(debugCodeLabel).left();
		final TextField debugCodeField = new TextField(null, core.getDefaultSkin());
		optionsTable.add(debugCodeField).fillX();
		
		optionsTable.top();
		
		optionsTable.row();
		
		TextButton keybindSettings = new TextButton("Set Controls",  core.getDefaultSkin());
		keybindSettings.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				targetPosition.y = -0.5f*Gdx.graphics.getHeight();
			}
		});
		optionsTable.add(keybindSettings).colspan(2).fillX();
		
		optionsTable.row();
		
		TextButton graphicsSettings = new TextButton("Graphics",  core.getDefaultSkin());
		graphicsSettings.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				targetPosition.y = 1.5f*Gdx.graphics.getHeight();					
			}
		});
		optionsTable.add(graphicsSettings).colspan(2).fillX();
		addListener(new InputListener() {
			@Override
			public boolean keyUp(InputEvent event, int keycode) {
				if (keycode == Keys.ENTER) {
					Gdx.app.debug("Debug Field", debugCodeField.getText());
					if (debugCodeField.getText().equals("creative")) {
						Gdx.app.debug("Debug Field", "going to creative test room...");
						core.setScreen(new CreativeScreen(core, (MainMenu) core.getScreen(), sc.getSongList()));
					}
				}
				return super.keyUp(event, keycode);
			}
		});
	}
	
	public void saveOptions(Preferences prefs) {
		Gdx.app.debug("Preferences", "Saved all basic options page values.");
		prefs.putString("music dir", directoryField.getText());
	}
}
